#
# spec file for package devscripts
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define flavor %{nil}
%if "%{flavor}" == "checkbashisms"
  %define name_suffix -checkbashisms
%endif

%define _xsl_stylesheet %{_datadir}/xml/docbook/stylesheet/nwalsh/current/manpages/docbook.xsl
Name:           devscripts%{?name_suffix}
Version:        2.22.2
Release:        3.7
Summary:        Scripts to make the life of a Debian Package maintainer easier
License:        (Artistic-1.0 OR GPL-1.0-or-later) AND Artistic-2.0 AND GPL-2.0-only AND GPL-2.0-or-later AND GPL-3.0-or-later AND GPL-3.0-only AND SUSE-Public-Domain AND ISC
Group:          Development/Tools/Building
URL:            https://salsa.debian.org/debian/devscripts
Source:         https://salsa.debian.org/debian/devscripts/-/archive/v%{version}/devscripts-v%{version}.tar.bz2
# PATCH-FIX-OPENSUSE devscripts-fix-build.patch -- Fix docbook template directories path.
Patch0:         devscripts-fix-build.patch
# PATCH-FIX-OPENSUSE devscripts-fix-python-install-layout.patch -- Remove Debian's --install-layout=deb from setup.py.
Patch1:         devscripts-fix-python-install-layout.patch
# PATCH-FEATURE-OPENSUSE devscripts-debcommit-hg16.patch -- Mercurial cannot commit empty, fix it.
Patch2:         devscripts-debcommit-hg16.patch
BuildRequires:  bash-completion-devel
%if "%{flavor}" == ""
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  dpkg-devel >= 1.18.19
BuildRequires:  help2man
BuildRequires:  libxslt
%endif
BuildRequires:  perl
BuildRequires:  perl-macros
%if "%{flavor}" == ""
BuildRequires:  po4a
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  sgmltool
BuildRequires:  texlive-latex
BuildRequires:  zlib-devel
%endif
Requires:       checkbashisms >= %{version}
Requires:       dpkg
Requires:       html2text
Requires:       perl-File-HomeDir
Requires:       perl-IPC-Run
Requires:       perl-Moo
# provides same %_bindir/hardening-check binary
Conflicts:      hardening-check
Provides:       deb:%{_bindir}/debchange
%{?perl_requires}

%description
Collection of scripts for working on Debian packages.

Examples:
 - bts: A command-line tool for manipulating the Debian Bug
   Tracking System.
 - dcontrol: Remotely query package and source control files for
   all Debian distributions.
 - debchange/dch: Automagically add entries to debian/changelog
   files.
 - debsign, debrsign: Sign a .changes/.dsc pair without needing any
   of the rest of the package to be present; can sign the pair
   remotely or fetch the pair from a remote machine for signing.
 - diff2patches: Extract patches from a .diff.gz file placing them
    under debian/ or, if present, debian/patches.
 - licensecheck: Attempt to determine the license of source files.
 - uscan: Scan upstream sites for new releases of packages.

%if "%{flavor}" == "checkbashisms"
%package -n checkbashisms
Summary:        Tool for checking /bin/sh scripts for possible bashisms
License:        GPL-2.0-or-later
Group:          Development/Tools/Building
Provides:       deb:%{_bindir}/checkbashisms
Provides:       devscripts:%{_bindir}/checkbashisms
BuildArch:      noarch
%{?perl_requires}

%description -n checkbashisms
checkbashisms performs basic checks on /bin/sh shell scripts for
the possible presence of bashisms. It takes the names of the shell
scripts on the command line, and outputs warnings if possible
bashisms are detected.*
%endif

%prep
%autosetup -p1 -n devscripts-v%{version}

%if "%{flavor}" == "foo"
echo %{version} > version
%endif

%build
%if "%{flavor}" == ""
make %{?_smp_mflags} V=1 \
  XSL_STYLESHEET="%{_xsl_stylesheet}"
%endif

%install
%if "%{flavor}" == ""
%make_install \
  XSL_STYLESHEET="%{_xsl_stylesheet}"
%python3_fix_shebang
%endif

%if "%{flavor}" == "checkbashisms"
mkdir -p %{buildroot}%{_bindir}
sed -e "s/###VERSION###/%{version}/" scripts/checkbashisms.pl > %{buildroot}%{_bindir}/checkbashisms
chmod a+x %{buildroot}%{_bindir}/checkbashisms
install -D -m755 scripts/checkbashisms.bash_completion %{buildroot}%{_datadir}/bash-completion/completions/checkbashisms
%endif

# remove completion that was provided in older bash completion
%if 0%{?suse_version} <= 1500
rm %{buildroot}%{_datadir}/bash-completion/completions/bts
%endif

mkdir -p %{buildroot}%{_mandir}/man1/
%if "%{flavor}" == ""
install -Dpm 0644 scripts/*.1 -t %{buildroot}%{_mandir}/man1/
%endif
%if "%{flavor}" == "checkbashisms"
install -Dpm 0644 scripts/checkbashisms.1 -t %{buildroot}%{_mandir}/man1/
%endif

%if "%{flavor}" == ""
while read target link; do
    if [ -d $(dirname "%{buildroot}$link") ]; then
        ln -sf "$target" "%{buildroot}$link"
    fi
done < debian/links
%endif

# Fix documentation.
%if "%{flavor}" == ""
mkdir -p %{buildroot}%{_docdir}/
if [ "%{_datadir}/doc" != "%{_docdir}" ]; then
    mv %{buildroot}%{_datadir}/doc/devscripts %{buildroot}%{_docdir}/
fi
install -Dpm 0644 debian/changelog %{buildroot}%{_docdir}/devscripts/changelog
%endif

%if "%{flavor}" == ""
%files
%license debian/copyright COPYING
%doc %{_docdir}/devscripts/
%{_bindir}/*
%exclude %{_bindir}/checkbashisms
%{_datadir}/devscripts/
%{python3_sitelib}/devscripts/
%{python3_sitelib}/devscripts-*
%{perl_vendorlib}/Devscripts/
%{_datadir}/bash-completion/completions/*
%exclude %{_datadir}/bash-completion/completions/checkbashisms
%{_mandir}/man?/*.?%{?ext_man}
%exclude %{_mandir}/man1/checkbashisms.1%{?ext_man}
%endif

%if "%{flavor}" == "checkbashisms"
%files -n checkbashisms
%license debian/copyright COPYING
%{_bindir}/checkbashisms
%{_datadir}/bash-completion/completions/checkbashisms
%{_mandir}/man1/checkbashisms.1%{?ext_man}
%endif

%changelog
* Thu Jun 20 2024 pgajdos@suse.com
-  remove dependency on /usr/bin/python3 using
  %%python3_fix_shebang macro, [bsc#1212476]
* Fri May 24 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Fix minor issues:
  + Do not build devscripts main package (empty) in checkbashisms
    flavor.
  + Ensure the two flavors have different .src.rpm names, not
    overwriting each other.
* Tue May 21 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Mark %%{buildroot}%%{_bindir}/checkbashisms executable: sed … >
  %%{buildroot}%%{_bindir}/checkbashisms creates a non-executable,
  regular file.
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Tue Nov 28 2023 Frederic Crozat <fcrozat@suse.com>
- Move checkbashisms to a separate multibuild flavor, reduce
  build cycle when only checkbashisms is needed.
* Tue Jul 12 2022 Dirk Müller <dmueller@suse.com>
- update to 2.22.2:
  * who-permits-upload:
    + Fix fingerprint lookup, so it actually finds the user id
  * debsnap:
    + Add a -l option as the short version of --list.  Closes: #1006904
  * sadt:
    + Run autodep8 when looking for autopkgtests to run.
  * deprepro:
    + Add new options, to make it easier to debrepro against arbitrary source
    directories (i.e. not Debian packages):
  - -B, --build-command: specify custom build command
  - -a, --artifact-pattern: specify custom artifacts to be compared
    across builds
  - --no-copy: run commands against the source tree directly, i.e. don't
    copy it to a temporary build directory.
  * mk-origtargz:
    + Apply patch from Vasyl Gello to make Files-Included-<component> work.
  * Include the updated Portuguese translation.  Closes: #1011316
    Thanks to Américo Monteiro <a_monteiro@gmx.com>.
  * Run perltidy with the newer 20220217.
  * Bump Standards-Version to 4.6.1, no changes needed.
  * mk-origtargz:
    + Display compression/tar errors
  * wrap-and-sort:
    + Introduce an experimental mode using the RTS parser available with
    python-debian >= 0.1.43.  This will let wrap-and-sort retain comments.
    This feature is opt-in with a new flag.  MR: !237
    + Futher improvements to the RTS mode, now also supporting short indent
    (-s) among others.  MR: !263
  * deb-janitor:
    + Add a new 'review' subcommand.  MR: !261
  * wnpp-check:
    + Replace HTTP URLs with HTTPS.  Closes: #1002311, #902242; MR: !256
  * rc-alert, wnpp-alert, wnpp-check:
    + Allow curl to follow HTTP redirections.  MR: !257
  * wnpp-check:
    + Document -e,--exact in the --help output.  Closes: #1003254
  * Make pristine-tar a Suggests in Ubuntu, as it's not in main so it can't be
    a Recommends.  LP: #1885766
  * Don't build-depend on subversion on i386, skipping the test_uscan_svn
    test; this is to avoid a delta with Ubuntu, that doesn't have svn on i386.
  * debrebuild:
    + Use the new field_parse_binary_source() from libdpkg-perl >= 1.21.0
    if available.  MR: !249
  * test_uscan_mangle:
    + Use MGZREPACK to specify the expected file extension when necessary;
    otherwise, use the default file extension.
    + Add a workaround for testWatch4WebNonNativeMUT0(). MR: !258
    + Test use of filenamemangle with single and multiple upstream tarballs.
    + Modify helperWatch() to accept filenamemangled filenames.
    + Allow filenamemangling with multiple upstream tarballs.
  * Fix some spelling errors in code comments.  MR: !243
  * hardening-check:
    + Handle emtpy symble table by returning an unknown result for the
    stack-protector check.  MR: !223
  * salsa:
    + Add a new last_ci_status subcommand.  MR: !226
- drop devscripts-checkbashisms-early-fail.patch (upstream)
* Mon May  2 2022 Michal Hrusecky <michal.hrusecky@opensuse.org>
- Add missing uscan dependencies perl-{File-HomeDir,IPC-Run,Moo}
* Mon Nov 23 2020 Martin Liška <mliska@suse.cz>
- Add backport from master devscripts-checkbashisms-early-fail.patch.
* Tue Sep  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.19.5:
  * various fixes in scripts all around:
    + See /usr/share/doc/packages/devscripts/changelog
- Add conflicts on packages with the same binaries
* Tue Apr  2 2019 Martin Wilck <mwilck@suse.com>
- Fixed license tag as suggested by licensedigger.
* Thu Mar 28 2019 Martin Wilck <mwilck@suse.com>
- Changed download location for source tarball from Debian package
  pool to salsa.debian.org to avoid download errors in OBS.
  * format must be changed to tar.bz2, because salsa.debian.org
  doesn't support tar.xz.
  * verified identical contents of new and old tarball
* Sat Dec 15 2018 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 2.18.10:
  * See /usr/share/doc/packages/devscripts/changelog
- Rebase and rename devscripts-2.11.7-buildfix.patch to
  devscripts-fix-build.patch.
- Rebase and rename devscripts-2.15.1-remove-install-layout-deb.patch
  to devscripts-fix-python-install-layout.patch.
- Rebase and rename devscripts-2.11.7-debcommit-hg16.patch to
  devscripts-debcommit-hg16.patch (is it still relevant?).
- Kill support for ancient openSUSE and non-SUSE distributions.
- Spec clean-up.
* Sun Jan  4 2015 Denisart Benjamin <p.drouand@gmail.com>
- Update to version 2.15.1
  + see  /usr/share/doc/packages/devscripts/changelog for details
- Upstream moved to python3
  + Use python3-{devel,setuptools} instead of python-{devel,setuptools}
  That means compatibility with SLE11 is broken
- Remove now unapplied patches
  + devscripts-pod2man-no-utf8.patch
  + devscripts-old-File-Path.patch
- Adapt devscripts-2.11.7-remove-install-layout-deb.patch to upstream
  changes > devscripts-2.15.1-remove-install-layout-deb.patch
- Remove yet obsolete compatibility stuff
- Remove obsolete patch:
  * fix_pod_syntax.patch
* Mon Jul  1 2013 frank.lichtenheld@sophos.com
- update to 2.12.6 (current stable)
  * see /usr/share/doc/packages/devscripts/changelog for details
* Sat Jun 29 2013 asterios.dramis@gmail.com
- Added a patch (fix_pod_syntax.patch) to fix build with perl 5.18.
* Tue Feb 12 2013 frank.lichtenheld@sophos.com
- Make BuildArch: noarch for checkbashisms conditional to
  allow building on SLE 11.
* Mon Feb 11 2013 frank.lichtenheld@sophos.com
- separate checkbashisms package so that rpmlint can
  depend on it without depending on all the other stuff.
  (bnc#802887)
* Mon Feb  4 2013 coolo@suse.com
- update license to new format
* Fri Oct  5 2012 frank.lichtenheld@sophos.com
- extend License header according to review. (bnc#783729)
- add debian/changelog and debian/copyright to package
* Thu Sep 27 2012 frank.lichtenheld@sophos.com
- update to devscripts-2.12.4
  * dget: Fix CVE-2012-2241 (arbitrary file deletion)
  * dscverify: Fix CVE-2012-2240 (arbitrary code execution)
  * annotate-output: Fix to prevent symlink attack: don't delete
  safely-created file and reuse its name.  Instead, create temporary
  directory and create FIFOs therein.  Also, be sure to remove temporaries
  upon catchable signal.  Fixes CVE-2012-3500.
  * debdiff: Fix regression in exit code, introduced in 2.11.4.
  * see /usr/share/doc/packages/devscripts/changelog for details
* Fri Jul  6 2012 frank.lichtenheld@sophos.com
- no need to depend on a specific perl version
* Tue Jun 26 2012 frank.lichtenheld@sophos.com
- fix build on Fedora
  * fix path to XSL stylesheets
  * build require dpkg-devel since dpkg-parsechangelog
  is in there in Fedora
  * do not pretend that the Makefile honors %%_libexecdir
- fix scripts that use File::Path on SLE 11
* Tue Jun 26 2012 frank.lichtenheld@sophos.com
- package devscripts separately
* Mon May 21 2012 i@marguerite.su
- update to dpkg-1.16.3
  * see http://packages.debian.org/changelogs/pool/main/d/dpkg/dpkg_1.16.3/changelog
- update to debhelper 9.20120518
  * Fix versioned dependency on dpkg for xz options. Closes: #672895
  * dh_link: Doc improvement. Closes: #672988
- update to devscripts-2.11.7
  * see http://packages.debian.org/changelogs/pool/main/d/devscripts/devscripts_2.11.7/changelog
- reworked patch. remove version for archtable. for it's universal.
- add dh_make 0.60
  * see http://packages.debian.org/changelogs/pool/main/d/dh-make/dh-make_0.60/changelog
- add dh_autoreconf 6
  * see http://packages.debian.org/changelogs/pool/main/d/dh-autoreconf/dh-autoreconf_6/changelog
* Thu May  3 2012 frank.lichtenheld@sophos.com
- install missing parts of devscripts
  * install man pages installed by debian/manpages
  * install symlinks installed by debian/links
* Sun Jan 29 2012 frank.lichtenheld@sophos.com
- update to dpkg-1.15.8.12
  * Do not fail to unpack shared directories missing on the file system
  from packages being replaced by other packages. Debian Bug #631808
  * Defer hardlink renames so that there's never a point were the new
  file contents are accessible from the final path before they have
  been fsync()ed and cannot be executed causing ETXTBSY when trying
  to open the to be installed paths for writing. Debian Bug #635683
  * Add armhf support to ostable and triplettable.
  Debian Bugs #594179, #639674
* Tue Dec 20 2011 coolo@suse.com
- remove call to suse_update_config (very old work around)
* Sat Nov 26 2011 frank.lichtenheld@sophos.com
- update to dpkg-1.15.8.11
  * Do not segfault on "dpkg -i --no-act".
  * Fix typo in "dpkg-name --overwrite" argument parsing so that it actually
  works at all. Ubuntu Bug #728708
  * Fix dpkg-split to not corrupt binary part metadata when generating the
  split packages on 32-bit systems.
  * Fix a regression in dpkg-divert where using --rename led to a failure when
  the rename implies crossing file systems.
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Thu Mar 31 2011 flichtenheld@astaro.com
- Merge openSUSE:Tools changes with system:packagemanager changes
* Thu Mar 17 2011 mvyskocil@suse.cz
- split the u-a to separate spec file to reduce a build cycle
* Wed Mar 16 2011 mvyskocil@suse.cz
- update to dpkg-1.15.8.10
- update to debhelper-7.5.17
- update to devscripts-2.10.71
- see /usr/share/doc/packages/deb/*/changelog for details
- build and install update-alternatives as separate subpackage
- add download urls to source tags
- remove pushd/popd madness in %%prep, use only one cd ..
- convert sed archtable hackery to patch and refresh patches
- rewrite a architecture mugging in config.h to be more readable
* Fri Jan 28 2011 adrian@suse.de
- fix build on old distros
* Fri Jan 28 2011 flichtenheld@astaro.com
- install missing debhelper files
  - install dh
  - install Debian/Debhelper/Buildsystem/*.pm
* Thu Jul 29 2010 wolfgang.rosenauer@basyskom.de
- make 'debcommit -r' work with mercurial 1.6
* Fri Apr  9 2010 puzel@novell.com
- update to dpkg-1.15.6.1
- update to debhelper-7.4.17
- update to devscripts-2.10.62
  - see /usr/share/doc/packages/deb/*/changelog for details
- split deb-devel subpackage
* Fri Feb 19 2010 puzel@novell.com
- update to dpkg-1.15.5.6
- update to debhelper-7.4.15
- update to devscripts-2.10.61
  - see /usr/share/doc/packages/deb/*/changelog for details
* Wed Jan  6 2010 jengelh@medozas.de
- enable parallel building with smp_mflags
* Fri Dec 18 2009 wr@rosenauer.org
- try to fix older dists
* Wed Nov 25 2009 puzel@novell.com
- update to dpkg-1.15.5.2, debhelper-7.4.8, devscripts-2.10.58
  - huge number of changelogs - please see appropriate changelogs
  for details:
  - /usr/share/doc/packages/deb/debhelper/changelog
  - /usr/share/doc/packages/deb/dpkg/changelog
* Thu Nov 12 2009 wr@rosenauer.org
- include devscripts-2.10.55
- add sensible-editor helper script
* Thu Aug 13 2009 puzel@novell.com
- update to debhelper-7.3.12
  * dh: Allow creation of new sequences (such as to handle a patch
    target for quilt), by adding an add_command function to the
    sequence addon interface.
  * perl_build: Fix Build check to honor source directory setting.
  * perl_build: Avoid failing if forced to be used in dh_auto_clean
    when Build does not exist (ie due to being run twice in a row).
  * dh_builddeb: Fix man page typo.
  * dh_installdeb: In udeb mode, support the menutest and isinstallable
    maintainer scripts.
* Tue Aug  4 2009 puzel@novell.com
- update to debhelper-7.3.9
  * cmake: Avoid forcing rpath off as this can break some test suites.
    It gets stripped by cmake at install time.
* Mon Jul 27 2009 puzel@novell.com
- update to debhelper-7.3.8
  * First upload of buildsystems support to unstable.
    Summary: Adds --buildsystem (modular, OO buildsystem classes),
  - -sourcedirectory, --builddirectory, and support for cmake
    and ant.
  * python_distutils buildsystem: Build for all supported Python
    versions that are installed. Ensure that correct shebangs are
    created by using `python' first during build and install.
    Also build with python*-dbg if the package build-depends
    on them.
* Thu Jul 16 2009 puzel@novell.com
- update to debhelper-7.3.4
  * Add a versioned dep on perl-base, to get a version that supports
    GetOptionsFromArray.
  * dh_install: Fix support for the case where --sourcedir=debian/tmp/foo
    is used. Perl was not being greedy enough and the 'foo' was not stripped
    from the destination directory in this unusual case.
  * dh_install: Fix support for the case where debian/tmp is
    explicitly specified in filename paths despite being searched by
    default.
  * dh_install: Add test suite covering the last 5 bugs.
* Fri Jul  3 2009 puzel@novell.com
- update to debhelper-7.3.1
  * Modular object oriented dh_auto_* buildsystem support,
    contributed by Modestas Vainius
  - dh_auto_* --sourcedirectory can now be used to specify a source
    directory if sources and/or the whole buildsystem lives elsewhere
    than the top level directory.
  - dh_auto_* --builddirectory can now be used to specify a build
    directory to use for out of source building, for build systems
    that support it.
  - dh_auto_* --buildsystem can now be used to override the autodetected
    build system, or force use of a third-party class.
  - dh_auto_* --list can be used to list available and selected build
    systems.
  - Adds support for cmake.
  - For the perl_build build system, Build is used consistently
    instead of falling back to using the generated Makefile.
  - Historical dh_auto_* behavior should be preserved despite these
    large changes..
  * Move two more command-specific options to only be accepted by the commands
    that use them. The options are:
  - -sourcedir, --destdir
    If any third-party debhelper commands use either of the above options,
    they will be broken, and need to be changed to pass options to init().
  * Make dh not complain about unknown, command-specific options passed to it,
    and further suppress warnings about such options it passes on to debhelper
    commands. This was attempted incompletely before in version 7.2.17.
  * dh_install: Fix installation of entire top-level directory
    from debian/tmp.
  * dh_install: Handle correctly the case where a glob expands to
    a dangling symlink, installing the dangling link as requested.
  * dh_install: Fix fallback use of debian/tmp in v7 mode; a bug caused
    it to put files inside a debian/tmp directory in the package build
    directory, now that prefix is stripped.
  * dh_shlibdeps: Ensure DEBIAN directory exists, as dpkg-shlibdeps
    prints a confusing warning if it does not.
  * dh_auto_install: Pass --install-layout=deb to setup.py
    to support python 2.6.
  * Allow command-specific options to be passed to commands
    via dh without causing other commands to emit a getopt
    warning or deprecation message.
  * dh_installinfo: No longer inserts install-info calls into
    maintainer scripts, as that is now triggerized. Adds a dependency
    via misc:Depends to handle partial upgrades. Note that while
    dh_installinfo already required that info files had a INFO-DIR-SECTION,
    the new system also requires they have START-INFO-DIR-ENTRY and
    END-INFO-DIR-ENTRY for proper registration. I assume there will be
    some mass bug filing for any packages that do not have that.
* Fri Jun 12 2009 puzel@suse.cz
- update to debhelper-7.2.16
  * dh_gconf: Add missed half of postrm fragment removal.
* Thu Jun 11 2009 puzel@suse.cz
- update to debhelper-7.2.15
  * dh_strip, dh_shlibdeps: Add support for OCaml shared libraries.
  * dh_compress: Avoid compressing .svg and .sgvz files, since these
    might be used as images on a html page, and also to avoid needing
    to special case the .svgz extension when compressing svg.
  * dh_scrollkeeper: Now a deprecated no-op.
  * dh_gconf: Remove postrm fragment that handled schema migration
    from /etc to /usr.
* Thu May 21 2009 puzel@suse.cz
- update to debhelper-7.2.14
  * dh: Avoid writing log after override_dh_clean is run.
  * dh_auto_configure: Pass --skipdeps safely via PERL_AUTOINSTALL.
  * dh_auto_configure: Revert --skipdeps change
* Wed May 13 2009 puzel@suse.cz
- update to debhelper-7.2.11
  * dh: Support --with addon,addon,...
  * dh_auto_configure: Add --skipdeps when running Makefile.PL,
    to prevent Module::Install from trying to download dependencies.
  * Support debian/foo.os files to suppliment previous debian/foo.arch
    file support.
* Mon May 11 2009 puzel@suse.cz
- update to debhelper-7.2.10
  * Close COMPAT_IN filehandle.
  * dh_auto_configure: Clarify man page re adding configure
    parameters.
  * dh_auto_configure: Pass packlist=0 when running Makefile.PL,
    in case it is a Build.PL passthru, to avoid it creating
    the .packlist file.
* Wed May  6 2009 puzel@suse.cz
- update to debhelper-7.2.9
  * dh_fixperms: Ensure lintian overrides are mode 644.
  * dh_fixperms: Fix permissions of OCaml .cmxs files.
  * dh: Add --without to allow disabling sequence addons (particularly
    useful to disable the default python-support addon).
- split -lang subpackage
* Tue Apr 21 2009 puzel@suse.cz
- update to debhelper-7.2.8
  * dh_desktop: Now a deprecated no-op, since desktop-file-utils
    uses triggers.
  * Move dh sequence documentation to PROGRAMMING.
* Thu Apr 16 2009 puzel@suse.cz
- update to debhelper-7.2.7
  * fix calling the same helper for separate packages in the override of dh
    binary-indep/binary-arch
  * add --remaining-packages option
  * dh_icons: ignore gnome and hicolor themes (will be handled
    by triggers)
* Mon Apr  6 2009 puzel@suse.cz
- add a hack to detect architecture correctly (bnc#469337)
* Mon Mar 16 2009 puzel@suse.cz
- update to debhelper-7.2.6
  * examples files updated to add dh_bugfiles, remove obsolete
    dh_python
  * dh_auto_test: Support DEB_BUILD_OPTIONS=nocheck
  * set MODULEBUILDRC=/dev/null when running perl Build scripts
    to avoid ~/.modulebuildrc influencing the build
  * dh_installmenus: Revert removal of update-menus calls
* Mon Mar  9 2009 puzel@suse.cz
- update to debhelper-7.2.4
  * dh_makeshlibs: Fix --add-udeb, for real
  * dh_installmenus: Now that a triggers capable menu and dpkg are in
    stable, menu does not need to be explicitly run in maintainer
    scripts, except for packages with menu-methods files.
  * dh_installdocs: No longer add maintainer script code to call
    doc-base, as it supports triggers in stable.
  * dh_bugfiles: New program, contributed by Modestas Vainius.
  * dh: Override LC_ALL, not LANG.
  * dh_installchangelogs: Support -X to exclude automatic installation
    of specific upstream changelogs.
  * Compat level 4 is now deprecated.
  * dh_makeshlibs: Re-add --add-udeb support.
  * dh_shlibdeps: Remove --add-udeb switch (was accidentially added here).
* Thu Mar  5 2009 puzel@suse.cz
- update to debhelper-7.2.2
  * dh_installmodules: Give files in /etc/modprobe.d a .conf
    syntax, as required by new module-init-tools.
  * dh_installmodules: Add preinst and postinst code to handle
    cleanly renaming the modprobe.d files on upgrade.
  * Two updates to conffile moving code from wiki:
  - Support case where the conffile name is a substring of another
    conffile's name.
  - Support case where dpkg-query says the file is obsolete.
* Tue Mar  3 2009 puzel@suse.cz
- update to dpkg-1.15.0 and debhelper-7.2.1
  - huge number of changes, please see
    /usr/share/doc/packages/deb/dpkg/changelog and
  /usr/share/doc/packages/deb/debhelper/changelog
  for details
* Tue Jan 20 2009 puzel@suse.cz
- partially revert change from Aug 12 2008 (bnc#467332)
* Thu Dec 18 2008 puzel@suse.cz
- update debhelper to 7.1.1
  * dh_install(1): Order options alphabetically.
  * Fix some docs that refered to --srcdir rather than --sourcedir.
  * Add Vcs-Browser field.
  * Ignore unknown options in DH_OPTIONS.
* Wed Oct 29 2008 puzel@suse.cz
- update debhelper to 7.1.0
  * dh_installchangelogs: Fall back to looking for changelog files ending
    with ".txt".
  * dh_gencontrol: Ensure misc:Depends is set in substvars to avoid dpkg
    complaining about it when it's empty.
  * dh: Fix typo in example.
  * Allow individual debhelper programs to define their own special options
    by passing a hash to init(), which is later passed on the Getopt::Long.
  * Move many command-specific options to only be accepted by the command
    that uses them. Affected options are:
  - x, -r, -R, -l, -L, -m,
  - -include-conffiles, --no-restart-on-upgrade, --no-start,
  - -restart-after-upgrade, --init-script, --filename, --flavor, --autodest,
  - -libpackage, --add-udeb, --dpkg-shlibdeps-params,
  - -dpkg-gencontrol-params, --update-rcd-params, --major, --remove-d,
  - -dirs-only, --keep-debug, --version-info, --list-missing, --fail-missing,
  - -language, --until, --after, --before, --remaining, --with
  * If any third-party debhelper commands use any of the above options,
    they will be broken, and need to be changed to pass options to init().
  * To avoid breaking rules files that pass options to commands that do not
    use them, debhelper will now only warn if it encounters an unknown
    option. This will be converted back to an error later.
* Tue Sep 16 2008 mrueckert@suse.de
- do not package update-alternatives it conflicts with the required
  package update-alternatives
* Tue Sep  2 2008 prusnak@suse.cz
- updated to 1.14.21
  * lots of fixes - see ChangeLog
- enabled SELinux support [Fate#303662]
* Mon Sep  1 2008 puzel@suse.cz
- update debhelper to 7.0.17
  * dh_auto_install: Fix man page, was referring to dh_auto_clean.
  * dh_gencontrol: Drop the Homepage field from udebs. Closes debian bug #492719
  * Typo. Closes debian bug #493062
  * dh_auto_install: Improve check for MakeMaker, to avoid passing PREFIX
    if the Makefile was generated by Module::Build::Compat. Closes debian bug #496157
* Tue Aug 12 2008 puzel@suse.cz
- fix paths
  * install perl stuff to %%{perl_vendorlib}/Debian where it is
    expected by alien
* Mon Aug 11 2008 coolo@suse.de
- fix paths
* Mon Jul 21 2008 puzel@suse.cz
- update debhelper to 7.0.16
  * dh: Avoid passing --with on to subcommands. Closes debian bug #490886
  * dh_installchangelogs: When searching for changelog in v7 mode, skip
    empty files. Closes debian bug #490937
* Fri Jul 18 2008 puzel@suse.cz
- update debhelper to 7.0.15
  * dh_clean: Do not delete *-stamp files in -k mode in v7. Closes debian bug #489918
* Tue Jul  8 2008 puzel@suse.cz
- update debhelper to 7.0.14
  * load python-support sequence file first, to allow ones loaded later to disable it
* Mon Jul  7 2008 puzel@suse.cz
- update dpkg to 1.14.19
  * a lot of changes and bugfixes
  * for complete changelog see program sources or
    /usr/share/doc/packages/deb/dpkg/changelog
  * removed dpkg-gcc4.patch - compiles fine without it
  * removed dpkg-make.patch, dpkg-automake.diff, dpkg-strip.patch
  * not needed anymore because of heavy changes in the build system
  * removed dpkg_1.10.23-doc.patch - fixed in upstream
- update debhelper to 7.0.13
  * a lot of changes and bugfixes
  * for complete changelog see program sources or
    /usr/share/doc/packages/deb/debhelper/changelog
  * debhelper-no-localized-manpages.diff - do not use po4a to generate
    localized documentation
- dpkg is now built by configure/make
- debhelper is now built by make
* Thu Jul 26 2007 dmueller@suse.de
- remove config.guess dependency completely
* Tue Jul 24 2007 dmueller@suse.de
- link the config.guess from automake
* Sun Apr 22 2007 ro@suse.de
- use texlive for building
* Fri Mar 30 2007 aj@suse.de
- Adjust BuildRequires.
* Fri Aug 18 2006 aj@suse.de
- Fix build with new make.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 13 2006 schwab@suse.de
- Don't strip binaries.
* Wed Dec 21 2005 ro@suse.de
- remove unpackaged symlinks
* Thu Sep  8 2005 mjancar@suse.cz
- package missing dpkg-{architecture,scanpackages,scansources} (#106239)
* Thu May 12 2005 meissner@suse.de
- use RPM_OPT_FLAGS
* Fri Apr  8 2005 uli@suse.de
- fixed to build with GCC4
* Thu Feb 10 2005 rengelhard@suse.de
- update dpkg to 1.10.27 (just translation updates)
* Thu Jan 20 2005 ro@suse.de
- update dependency: html2txt -> html2text
* Wed Jan 12 2005 rengelha@suse.de
- update dpkg to 1.10.26
* Wed Jan  5 2005 rengelhard@suse.de
- update debhelper to 4.2.30
* Tue Jan  4 2005 rengelhard@suse.de
- update debhelper to 4.2.29
* Wed Dec 15 2004 rengelhard@suse.de
- update debhelper to 4.2.28
* Mon Dec 13 2004 rengelhard@suse.de
- update debhelper to 4.2.27
* Tue Nov 16 2004 rengelhard@suse.de
- update dpkg to 1.10.25
* Thu Nov 11 2004 rengelhard@suse.de
- update debhelper to 4.2.24
* Fri Oct 29 2004 rengelhard@suse.de
- update debhelper to 4.2.23
* Wed Oct 27 2004 rengelhard@suse.de
- update dpkg to 1.10.24
* Wed Oct 13 2004 rengelhard@suse.de
- update debhelper to 4.2.21
* Tue Sep  7 2004 ro@suse.de
- remove stuff now present in own update-alternatives package
* Thu Aug 19 2004 mcihar@suse.cz
- update debhelper to 4.2.19
- update dpkg to 1.10.23
- use sed rather than patches
- remove patches accepted in upstream
* Mon May 31 2004 mcihar@suse.cz
- update debhelper to 4.2.10
- update dpkg to 1.10.21
* Thu Mar  4 2004 mcihar@suse.cz
- no root for build
- revert to manual debhelper installation as installation using
  debhelper needs dpkg and debhelper installed
* Wed Mar  3 2004 mcihar@suse.cz
- debhelper has debian/control file, so do not install manually
- update debhelper to 4.2.4
- update dpkg to 1.10.18.1
* Tue Jan 27 2004 ro@suse.de
- debhelper has no debian/control file, so install manually
* Tue Jan 27 2004 mcihar@suse.cz
- install debhelper man pages on correct place
* Mon Jan 26 2004 mcihar@suse.cz
- updated debhelper to 4.1.88 and dpkg to 1.10.18
* Wed Aug 20 2003 mjancar@suse.cz
- require the perl version we build with
* Thu Aug  7 2003 mcihar@suse.cz
- updated debhelper to 4.1.57
* Mon Jul 28 2003 schwab@suse.de
- Fix format string.
- Fix undefined use of longjmp.
- Use perl_vendorlib.
* Wed Jun 18 2003 mcihar@suse.cz
- updated debhelper to 4.1.47 (mostly fixes in dh_python)
- included directories for translated man pages
- use find_lang
* Tue May 13 2003 mcihar@suse.cz
- updated debhelper to 4.1.43
- updated dpkg to 1.1.10
* Tue Apr  8 2003 mcihar@suse.cz
- updated debhelper to 4.1.40
- fixed problems with new coreutils
* Thu Mar  6 2003 mcihar@suse.cz
- configuration files under /etc marked as %%config
* Thu Jan 30 2003 mcihar@suse.cz
- updated debhelper to 4.1.29:
  * Added a dh_python command.
  * Various fixes.
* Wed Nov 13 2002 mcihar@suse.cz
- updated dpkg to 1.10.9, major changes:
  * Make the multiline regex have an upper bound, instead of being
    unbounded, as newer perls have a larger stack frame, which cause them
    to segfault quicker with larger inputs.
  * Fix segfault in md5sum if the file being checked doesn't exist.
  * Fix extraction of md5sum in dpkg-scanpackages.
  * Handle directories better in md5sum.
  * Fix several read pass buffer bugs, and a memleak.
  * Fix segfault when --auto-deconfigure is given.
- updated debhelper to 4.1.20, major changes:
  * typo in dh_shlibdeps(1)
  * dh_fixperms: Make sure .pm files are 0644.
  * dh_strip: detect and don't strip debug/*.so files.
  * Various improvements to debhelper(1).
  * Clarified dh_perl man page.
  * Fixed excessive escaping around terms in DH_EXCLUDE_FIND.
  * Patch from Andrew Suffield to make dh_perl understand #!/usr/bin/env perl
- included part of postinst script from debian package
* Mon Nov 11 2002 ro@suse.de
- changed neededforbuild <sp> to <opensp>
- changed neededforbuild <sp-devel> to <>
* Wed Aug 28 2002 mcihar@suse.cz
- corrected requires
* Wed Aug  7 2002 mcihar@suse.cz
- updated to debhelper 4.1.3:
  * various bugfixes
  * removed /usr/doc manglement code from postinst and prerm
  * removed dh_installxaw
  * dh_installchangelogs installs debian/NEWS
- updated to dpkg 1.10.4:
  * plenty of bugfixes and new switches
  * added Large File Summit extension
  * added manpages for dpkg.cfg and dselect.cfg
  * updated translations
  * install archtable into /usr/share/dpkg/
- dpkg is now build by debian/rules not by script in spec
- removed md5sum.1 start-stop-daemon.8 install-info.8 manpages also
  for other locales (these programs are not installed)
* Tue Jun 11 2002 mcihar@suse.cz
- updated to debhelper 4.0.11 and dpkg 1.9.21
* Mon Aug 13 2001 ro@suse.de
- changed neededforbuild <sp_libs> to <sp-devel>
* Fri Jun  8 2001 cihlar@suse.cz
- fixed to compile with new autoconf
* Tue Apr 24 2001 cihlar@suse.cz
- fixed warnings on ia64
* Wed Apr 18 2001 cihlar@suse.cz
- fixed to compile
* Mon Mar  5 2001 cihlar@suse.cz
- dpkg updated to version 1.8.3.1
- debhelper updated to version 3.0.8
* Tue Dec  5 2000 schwab@suse.de
- Fix broken declaration.
* Tue Oct 31 2000 cihlar@suse.cz
- update to version 1.6.14
- bzipped sources
* Tue May 23 2000 cihlar@suse.cz
- added files in /etc and /var to %%files
* Mon May 22 2000 cihlar@suse.cz
- removed install-info and start-stop-daemon
* Mon May 15 2000 schwab@suse.de
- Fixed for ia64.
* Wed May  3 2000 cihlar@suse.cz
- package created - version 1.4.0.35 (debhelper 1.1.24)
